-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}

local function onReset()
  electrics.values['weightboxMove_position'] = 0
  electrics.values['weightboxMove_input'] = 0
  electrics.values['weightboxMove_reset'] = 0
  electrics.values['pushDown_position'] = 0
  electrics.values['pushDown_activation'] = 0
end

local function updateGFX(dt) -- ms

  local gearRatio = v.variables["$gearRatio"].val
  local tripValue = v.variables["$trip"].val
  local weightBoxPosition = electrics.values['weightboxMove_position']
  local pushDownPosition = electrics.values['pushDown_position']
  
  gearRatio = gearRatio / 3
  tripValue = tripValue / 100 * -1
  
  if electrics.values['weightboxMove_reset'] == 1 then 
    weightBoxPosition  = weightBoxPosition  + 0.075 * dt
    if weightBoxPosition  >= 0 then
      electrics.values['weightboxMove_reset'] = 0
    end
  else
    --use keyboard inputs to move weight box
    weightBoxPosition = weightBoxPosition  + electrics.values['weightboxMove_input'] * dt * 0.25
  end  
  
  --use wheel angular velocity to move weight box
  weightBoxPosition  = weightBoxPosition  + electrics.values['avgWheelAV'] * dt * 0.0055 * gearRatio
  
  if electrics.values['weightboxMove_position'] <= tripValue and electrics.values['weightboxMove_reset'] == 0
  then --we're in front of the trip point
    electrics.values['pushDown_activation'] = 1
  end
  
  electrics.values['weightboxMove_position'] = math.min(-0.0, math.max(-1, weightBoxPosition))  
  
  if electrics.values['pushDown_activation'] == 1 then
    electrics.values['pushDown_position'] = math.min(0.2, math.max(-0, (electrics.values['pushDown_position'] + 0.1 * dt)))
  else
    electrics.values['pushDown_position'] = math.min(0.2, math.max(-0, (electrics.values['pushDown_position'] - 0.2 * dt)))
  end
  
end

local function weightboxMove(value)
  electrics.values.weightboxMove_input = value
  --using keyboard inputs cancels any weight box resets
  electrics.values['weightboxMove_reset'] = 0
end

local function weightboxReset()
  --electrics.values['weightboxMove_position'] = 0.001
  electrics.values['weightboxMove_reset'] = 1
  electrics.values['pushDown_activation'] = 0
end

-- public interface
M.onInit    = onReset
M.onReset   = onReset
M.updateGFX = updateGFX
M.weightboxMove = weightboxMove
M.weightboxReset = weightboxReset

return M
